No docutils, pandoc, or any other tricks! Just a `README.md` and a `setup.py`.

See the source for this project here:
<https://github.com/di/markdown-description-example>.

Instructions to do this for your project are here:
<https://dustingram.com/articles/2018/03/16/markdown-descriptions-on-pypi>

## What we can do:

We can do *italics* and **bold text**.

* Lists
* Are
* Fun
* Too
  * (But please use responsibly)

Code blocks:
```
>>> pypi_supports_markdown
True
```

And much much more!